==> retext-mapbox-standard-1.0.0.tgz: package/index.js <==
var nlcstToString = require('nlcst-to-string');
var visit = require('unist-util-visit');
var isLiteral = require('nlcst-is-literal');
var forbidden = require('./forbidden');
var acronyms = require('./acronyms');

function toSet(list) {
    var s = {};
    list.forEach(function(item) {
        s[item] = true;
    });
    return s;
}

var acronymsSet = toSet(acronyms);
var acronymsLowercase = acronyms.reduce(function(set, a) {
    set[a.toLowerCase()] = a;
    return set;
}, []);

/**
 * Get a string value from a node.
 *
 * @param {NLCSTNode} node - NLCST node.
 * @return {string} - Normalized and stringified `node`.
 */
function toString(node) {
    return nlcstToString(node).replace(/['’-]/g, '');
}

/**
 * Get the value of multiple nodes
 *
 * @param {Array.<NLCSTNode>} node - NLCST nodes.
 * @return {string} - Value of `node`.
 */
function valueOf(node) {
    return nlcstToString({
        'children': node
    });
}

/**
 * Factory to create a visitor which warns on `file`.
 *
 * @param {File} file - Virtual file.
 * @return {Function} - Paragraph visitor.
 */
function factory(file) {
    /**
     * Search `node` for violations.
     *
     * @param {NLCSTParagraphNode} node - Paragraph.
     */
    return function (node) {
        var matches = {};
        var id;
        var pattern;

        /*
         * Find offending words.
         */

        visit(node, 'WordNode', function (child, position, parent) {
            var length;
            var result;

            if (isLiteral(parent, position)) {
                return;
            }

            var stringValue = toString(child)
            var value = toString(child).toLowerCase();
            var index = -1;
            if (forbidden.hasOwnProperty(stringValue)) {
              file.warn(forbidden[stringValue], child);
            }
            if (acronymsLowercase.hasOwnProperty(value) &&
               !acronymsSet.hasOwnProperty(stringValue)) {
              file.warn(stringValue + ' should be styled ' + acronymsLowercase[value], child);
            }
        });
    };
}
/**
 * Transformer.
 *
 * @param {NLCSTNode} cst - Syntax tree.
 * @param {VFile} file - Virtual file.
 */
function transformer(cst, file) {
    visit(cst, 'ParagraphNode', factory(file));
}

/**
 * Attacher.
 *
 * @return {Function} - `transformer`.
 */
function attacher() { return transformer; }

/*
 * Expose.
 */

module.exports = attacher;

==> retext-mapbox-standard-1.2.1.tgz: package/index.js <==
var nlcstToString = require('nlcst-to-string');
var visit = require('unist-util-visit');
var isLiteral = require('nlcst-is-literal');
var brands = require('./brands');
var forbidden = require('./forbidden');
var acronyms = require('./acronyms');

function toSet(list) {
    var s = {};
    list.forEach(function(item) {
        s[item] = true;
    });
    return s;
}

var forbiddenSet = toSet(forbidden);
var acronymsSet = toSet(acronyms);
var acronymsLowercase = acronyms.reduce(function(set, a) {
    set[a.toLowerCase()] = a;
    return set;
}, []);

/**
 * Get a string value from a node.
 *
 * @param {NLCSTNode} node - NLCST node.
 * @return {string} - Normalized and stringified `node`.
 */
function toString(node) {
    return nlcstToString(node).replace(/['’-]/g, '');
}

/**
 * Get the value of multiple nodes
 *
 * @param {Array.<NLCSTNode>} node - NLCST nodes.
 * @return {string} - Value of `node`.
 */
function valueOf(node) {
    return nlcstToString({
        'children': node
    });
}

/**
 * Factory to create a visitor which warns on `file`.
 *
 * @param {File} file - Virtual file.
 * @return {Function} - Paragraph visitor.
 */
function factory(file) {
    /**
     * Search `node` for violations.
     *
     * @param {NLCSTParagraphNode} node - Paragraph.
     */
    return function (node) {
        var matches = {};
        var id;
        var pattern;

        /*
         * Find offending words.
         */

        visit(node, 'WordNode', function (child, position, parent) {
            var length;
            var result;

            if (isLiteral(parent, position)) {
                return;
            }

            var stringValue = toString(child)
            var value = toString(child).toLowerCase();
            var index = -1;
            if (forbiddenSet.hasOwnProperty(value)) {
              file.warn(value + ' is forbidden.', child);
            }
            if (brands.hasOwnProperty(stringValue)) {
              file.warn(brands[stringValue], child);
            }
            if (acronymsLowercase.hasOwnProperty(value) &&
               !acronymsSet.hasOwnProperty(stringValue)) {
              file.warn(stringValue + ' should be styled ' + acronymsLowercase[value], child);
            }
        });
    };
}
/**
 * Transformer.
 *
 * @param {NLCSTNode} cst - Syntax tree.
 * @param {VFile} file - Virtual file.
 */
function transformer(cst, file) {
    visit(cst, 'ParagraphNode', factory(file));
}

/**
 * Attacher.
 *
 * @return {Function} - `transformer`.
 */
function attacher() { return transformer; }

/*
 * Expose.
 */

module.exports = attacher;
